#!/bin/bash
#Serotype prediction based on protein input sequences & input must be in the format that contains amino acid fasta sequences of individual coding regions of the query

rm -rf sult_*
rm -rf serout_*
rm -rf wz*.txt
rm -rf wbap.txt
rm -rf wcaj.txt
rm -rf sertp_*
rm -rf resulvt*.txt
rm -rf newfas.fasta

#input
valb=$2 #Query Gene type
valc=$3 #Alignment type
ncnmm=$1 #Input fasta file
mo=$valc
#processing of input query file
cp $ncnmm newfas.fasta
ncnm=`echo $ncnmm | cut -d "." -f1 | rev | cut -d"/" -f1  | rev`
kppath=`echo $ncnmm | cut -d "." -f1 | rev | cut -d"/" -f2-  | rev`
kpath=$kppath"/"

echo "NCNM: $ncnm"

#Creating ouput directory
mkdir output_kpam
mkdir output_kpam/dir_$ncnm

#cutoff considered for serotype prediction, refer flowchart(Figure in manuscript)
pp_ctf1=100
pp_ctf2=98
pp_ctf3=95
pp_ctf4=90

pp_lnctf=70

#scnt=1

#ch=`cat new.fasta | tail -n +2 | tr -d "\r\n" | sed ':;s/\(.\)\(.*\)\1/\1\2/;t'`

#number of coding regions indicated by ">" in the input query
scnt=`grep -i "^>" newfas.fasta | wc -l`
echo "SCNT: $scnt"

makeblastdb -in kantgn_prot.fasta -dbtype prot -out dict_pt

strt=1
fnsh=$scnt

for ((x=$strt; x<=$fnsh; x=$x+1))
do
    if [ $x -ne $scnt ]
    then
	echo "X: $x"
	fseqh=`grep -i "^>" newfas.fasta | head -$x | tail -1 | awk '{print $1}'`
	y=`expr $x + 1`
	fseql=`grep -i "^>" newfas.fasta | head -$y | tail -1 | awk '{print $1}'`
	sed -n "/$fseqh/,/$fseql/p" newfas.fasta | sed '$ d' > new$x.fasta
    else
	echo "LAST"
	echo "X: $x"
	fseqh=`grep -i ">" newfas.fasta | head -$x | tail -1 | awk '{print $1}'`
	sed -n "/$fseqh/,/ /p" newfas.fasta > new$x.fasta
    fi

    #makeblastdb -in kantgn_prot.fasta -dbtype prot -out dict_pt
    blastp -db dict_pt -query new$x.fasta -outfmt 6 > output_$x.out
    blastp -db dict_pt -query new$x.fasta -outfmt 0 -out alignmnt_$x.txt

    echo "Protein_$x results:" >> result.csv
    echo -e "Query,Target (Database sequence),% Identity,Alignment length,No. of mismatches,No. of gap opens,Start position in query,End position in query,Start position in target,End position in target,E-value,Bit-score" >> result.csv
    while read -r line || [[ -n $line ]]; do
	a=`echo $line |awk '{print $1}'`
	b=`echo $line |awk '{print $2}'`
	c=`echo $line |awk '{print $3}'`
	d=`echo $line |awk '{print $4}'`
	e=`echo $line |awk '{print $5}'`
	f=`echo $line |awk '{print $6}'`
	g=`echo $line |awk '{print $7}'`
	h=`echo $line |awk '{print $8}'`
	i=`echo $line |awk '{print $9}'`
	j=`echo $line |awk '{print $10}'`
	k=`echo $line |awk '{print $11}'`
	l=`echo $line |awk '{print $12}'`
	m=`echo $line |awk '{printf "%3i", $3}'`
	echo $a,$b,$c,$d,$e,$f,$g,$h,$i,$j,$k,$l>>result.csv
	if [ $m -ge $pp_ctf2 ] && [ $d -ge $pp_lnctf ]; then
	    p=`echo $b | cut -d "|" -f3`
	    q=`echo $p | cut -d "_" -f2`
	    r=`echo $b |cut -d "|" -f4`
	    s=`echo $b |cut -d "|" -f2`
	    echo -e "$q   - $r   - $c   - $d   - $l - $s">>resulvt_$x.txt
	    
	else
	    continue;
	fi
    done<output_$x.out
    cat resulvt_$x.txt |awk '{print $1}' | sort -k1 -u > sult_$x.txt

    grep -i "100.00" resulvt_$x.txt> result_hndrd.txt
    if [ -s "result_hndrd.txt" ];
    then
	awk '{print $1}' result_hndrd.txt | sort -k1 -u> sult_$x.txt
    fi
done

grep -i "wzi" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wzi.txt
grep -i "wza" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wza.txt
grep -i "wzb" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wzb.txt
grep -i "wzc" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wzc.txt
grep -i "wbap" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wbap.txt
grep -i "wzx" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wzx.txt
grep -i "wzy" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wzy.txt
grep -i "wcaj" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f2 | sort -u > wcaj.txt

find w*.txt -size  0 -print0 |xargs -0 rm --

wno=`cat wzi.txt | wc -l`

wziscr_o=`echo "scale=2; 100/$wno" | bc`

if [ $wno -gt 1 ] && [ $mo == "PP" ]
then
    #cp /var/www/K-PAM/ncbi-blast-2.7.1+-src/c++/ReleaseMT/bin/blast_prdctn_2.sh .
    #cp /var/www/K-PAM/ncbi-blast-2.7.1+-src/c++/ReleaseMT/bin/wzi_prot.fasta .
    pwfno=`ls resulvt_*.txt | wc -l`
    if [ $pwfno -gt 1 ]
       then
	   wfno=`grep -i "wzi" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f1 | sort | uniq | wc -l`
    else
	wfno=1
    fi

    for (( ws=1; ws<=$wfno; ws=$ws+1 ))
    do
	if [ $pwfno -gt 1 ]
	then
	    wfi=`grep -i "wzi" resulvt_*.txt | awk '{print $1}' | cut -d ":" -f1 | sort | uniq | head -$ws | tail -1 | cut -d "_" -f2 | cut -d "." -f1`
	else
	    wfi=`ls resulvt_*.txt | cut -d "_" -f2 | cut -d "." -f1`
	fi
	
	sed s/some.fasta/new${wfi}.fasta/g blast_prdctn_2.sh |sed s/gene/wzi/g | sed s/MOL/PP/g | sed "s/output/outputw_$wfi/g" | sed "s/align/alignw_$wfi/g" | sed s/result/resultw${wfi}/g >filew$wfi.sh
	chmod 777 filew$wfi.sh
	./filew$wfi.sh
	cat resultw$wfi"1.txt" > wzi.txt
	cat wzi.txt > sult_$wfi.txt
	wsern=`cat wzi.txt | wc -l`
	cp resulvt_$wfi.txt resulvtwhl_$wfi.txt
	rm resulvt_$wfi.txt
	for (( wzn=1; wzn<=$wsern; wzn=$wzn+1 ))
	do
	    wser=`cat wzi.txt | head -$wzn | tail -1`
	    grep -i $wser resultw$wfi.txt >> resulvt_$wfi.txt
	done
    done
fi

find w*.txt -size  0 -print0 |xargs -0 rm --

declare -A ntgnclr=( ["wzi"]=1 ["wza"]=2 ["wzb"]=3 ["wzc"]=4 ["wbap"]=5 ["wzx"]=6 ["wzy"]=7 ["wcaj"]=5)

declare -A ntgnordr=( ["wzi"]=1 ["wza"]=2 ["wzb"]=4 ["wzc"]=5 ["wbap"]=8 ["wzx"]=7 ["wzy"]=6 ["wcaj"]=3)

for fln in wzi.txt wza.txt wzb.txt wzc.txt wbap.txt wzx.txt wzy.txt wcaj.txt
do
    if [ -e $fln ]
    then
	rscore=1.00
	nfln=`cat $fln | wc -l`
	nnfln=`echo "scale=2; 100/$nfln" | bc`
	mfln=`echo $fln | cut -d "." -f1`
	echo -e $mfln "\t" $nnfln "\t" "${ntgnclr[$mfln]}" "\t" "${ntgnordr[$mfln]}" "\t" $rscore >> gnrlbl.txt
    else
	rscore=0.97
	if [ $fln == "wbap.txt" ] && [ -e "wcaj.txt" ]
	then
	    mfln=`echo $fln | cut -d "." -f1`
	    echo -e $mfln "\t" 0 "\t" "${ntgnclr[$mfln]}" "\t" 0 "\t" $rscore >> gnrlbl.txt
	elif [ $fln == "wcaj.txt" ] && [ -e "wbap.txt" ]
	then
	    mfln=`echo $fln | cut -d "." -f1`
	    echo -e $mfln "\t" 0 "\t" "${ntgnclr[$mfln]}" "\t" 0 "\t" $rscore >> gnrlbl.txt
	else
	    
	    mfln=`echo $fln | cut -d "." -f1`
	    flnm=`grep -i $mfln output_*.out | sort -rnk12 | head -1 | awk '{print $1}' | cut -d ":" -f1`
	    nflnm=`echo $flnm | cut -d "_" -f2 | cut -d "." -f1`
	    ctper=`grep -i $mfln output_*.out | sort -rnk12 | head -1 | awk '{printf "%3i", $3}'`
	    if [ $ctper -gt 40 ]
	    then
		while read -r line || [[ -n $line ]]; do
		    a=`echo $line |awk '{print $1}'`
		    b=`echo $line |awk '{print $2}'`
		    c=`echo $line |awk '{print $3}'`
		    d=`echo $line |awk '{print $4}'`
		    e=`echo $line |awk '{print $5}'`
		    f=`echo $line |awk '{print $6}'`
		    g=`echo $line |awk '{print $7}'`
		    h=`echo $line |awk '{print $8}'`
		    i=`echo $line |awk '{print $9}'`
		    j=`echo $line |awk '{print $10}'`
		    k=`echo $line |awk '{print $11}'`
		    l=`echo $line |awk '{print $12}'`
		    m=`echo $line |awk '{printf "%3i", $3}'`
		    
		    if [ $m -ge $ctper ] && [ $d -ge 70 ]; then
			p=`echo $b | cut -d "|" -f3 | cut -d ":" -f1`
			q=`echo $p | cut -d "_" -f2`
			r=`echo $b |cut -d "|" -f4`
			if [[ -z "$r" ]]
			then
			    r=`echo $b | cut -d ":" -f2`
			fi
			s=`echo $b |cut -d "|" -f2`
			echo -e "$q   - $r   - $c   - $d   - $l - $s">>resulls_$nflnm.txt
			if [ $m -ge $pp_ctf3 ]
			then
			    echo -e "$q" >> sertp_$nflnm.txt
			fi
			
		    else
		    continue;
		    fi
		done<$flnm
		
		cat sertp_$nflnm.txt |awk '{print $1}' | sort -k1 -u > sult_$nflnm.txt
		cat resulls_$nflnm.txt |awk '{print $1}' | sort -k1 -u > $fln
		if [ -e $fln ]
		then
		    nfln=`cat sult_$nflnm.txt | wc -l`
		    nnfln=`echo "scale=2; 100/$nfln" | bc`
		    echo -e $mfln "\t" $nnfln "\t" "${ntgnclr[$mfln]}" "\t" "${ntgnordr[$mfln]}" "\t" $rscore >> gnrlbl.txt
		else
		    echo -e $mfln "\t" 0 "\t" "${ntgnclr[$mfln]}" "\t" 0 "\t" $rscore >> gnrlbl.txt
		fi
	    else
		echo -e $mfln "\t" 0 "\t" "${ntgnclr[$mfln]}" "\t" 0 "\t" $rscore >> gnrlbl.txt
	    fi
	fi
	
    fi

done

RS8[8]=1.00; RS8[7]=0.99; RS8[6]=0.99; RS8[5]=0.98; RS8[4]=0.96; RS8[3]=0.91; RS8[2]=0.83; RS8[1]=0.77;
RS7[7]=1.00; RS7[6]=1.00; RS7[5]=0.99; RS7[4]=0.97; RS7[3]=0.92; RS7[2]=0.84; RS7[1]=0.78;
RS6[6]=1.00; RS6[5]=0.99; RS6[4]=0.97; RS6[3]=0.92; RS6[2]=0.84; RS6[1]=0.78;
RS5[5]=1.00; RS5[4]=0.98; RS5[3]=0.93; RS5[2]=0.85; RS5[1]=0.79;
RS4[4]=1.00; RS4[3]=0.95; RS4[2]=0.86; RS4[1]=0.80;
RS3[3]=1.00; RS3[2]=0.91; RS3[1]=0.85;
RS2[2]=1.00; RS2[1]=0.93;
RS1[1]=1.00;

RRF1=`awk '{print $4}' gnrlbl.txt | sort | tail -1`

if [ $mo == "NP" ] || [ $mo == "PP" ]
then
    for fln in wzi wza wzb wzc wbap wzx wzy wcaj
    do
	RRF2=`grep -i $fln gnrlbl.txt | awk '{print $4}'`
	RRF=RS$RRF1[$RRF2]
	rscore=`grep -i $fln gnrlbl.txt | awk '{print $5}'`
	nnfln=`grep -i $fln gnrlbl.txt | awk '{print $2}'`
	
	frs=`echo "scale=2; $nnfln * ${!RRF} * $rscore" | bc -l`
	mfln=`grep -i $fln gnrlbl.txt | awk '{print $1}'`
	flnclr=`grep -i $fln gnrlbl.txt | awk '{print $3}'`
	echo -e $mfln "\t" $frs "\t" $flnclr  >> gnrlblx.txt
    done
else
    cp gnrlbl.txt gnrlblx.txt
fi

chmod 777 gnrlblx.txt
find w*.txt -size  0 -print0 |xargs -0 rm --

chmod 777 sult*.txt
find sult*.txt -size  0 -print0 |xargs -0 rm --
#bash link2.sh | tail -n +3 | head -n -1 | awk '{print $3}' | tr '[:upper:]' '[:lower:]' > new_combine.txt
bash link2.sh | grep -i "sult" | awk '{print $3}' | tr '[:upper:]' '[:lower:]' > new_combine.txt
cp new_combine.txt new_combine_pre.txt


serchtn=`bash link2.sh | grep -i "sult" | awk '{print $3}' | tail -1 | tr '[:upper:]' '[:lower:]'`
chtn=`cat new_combine.txt | wc -l`



if [ $chtn -gt 1 ]
then
    for (( ng=1; ng<=$chtn; ng=$ng+1 ))
    do
	sergn=`cat new_combine_pre.txt | head -$ng | tail -1`

	nkantg=`grep -i $sergn sult*.txt | cut -d ":" -f1 | sort -u | wc -l`

	if [ $nkantg -ge 3 ]
	   then
	       if [ "$sergn" == "k33" ] || [ "$sergn" == "k40" ]
	       then
		   rm wzi.txt
	       elif [ "$sergn" == "k34" ]
	       then
		   rm wzx.txt
	       elif [ "$sergn" == "k50" ]
	       then
		   rm wzb.txt wzc.txt wzx.txt wzy.txt
	       elif [ "$sergn" == "kl107" ]
	       then
		   rm wzx.txt wzy.txt
	       elif [ "$sergn" == "k29" ] || [ "$sergn" == "k71" ] || [ "$sergn" == "kl108" ] || [ "$sergn" == "kl109" ]
	       then
		   rm wzy.txt
	       elif [ "$sergn" == "kl110" ] || [ "$sergn" == "kl113" ] || [ "$sergn" == "kl116" ] || [ "$sergn" == "kl118" ]
	       then
		   rm wzy.txt
	       elif [ "$sergn" == "kl147" ] || [ "$sergn" == "kl152" ] || [ "$sergn" == "kl157" ] || [ "$sergn" == "kl158" ] || [ "$sergn" == "kl161" ]
	       then
		   rm wzy.tx
	       fi
	fi
	
	nsergn=`bash link2.sh | grep -i "sult" | grep -i $sergn | awk '{print $1}' | head -$ng | tail -1 | awk -F'/' '{ print NF }'`
	#nofgenes=`bash link2.sh | grep -i "records" | awk '{print $4}' | tail -1`
	#mxnofgns=`bash link2.sh | grep -i "sult" | awk '{print $1}' | awk -F'/' '{ print NF }' | sort | tail -1`
	
	if [ $nsergn -eq 7 ]
	then
	    
	    echo $sergn > new_combine.txt
	    
	elif [ $nsergn -lt 7 ] && [ $nsergn -ge 4 ]
	then
	    zx=`ls sult*.txt | wc -l`
	    if [ $nsergn -eq zx ]
	    then
		if [ $sergn == $serchtn ]
		then
		    echo $sergn > new_combine.txt
		else
		    echo $sergn > new_combine.txt
		fi
	    else
		if [ $sergn == $serchtn ]
		then
		    yx=`grep -L $sergn sult*.txt | wc -l`

		    for (( nyx=1; nyx<=$yx; nyx=$nyx+1 ))
		    do
			xx=`grep -L $sergn sult*.txt | head -$nyx | tail -1 | cut -d "_" -f2 | cut -d "." -f1`

			grep -i $sergn"|" output_$xx.out | awk '$3 >= 95.0' > serout_$xx.out

			cp sult_$xx.txt old_sult_$xx.txt
			rm sult_$xx.txt
			
			if [ -s "serout_$xx.out" ]
			then
			    while read -r line || [[ -n $line ]]; do
				a=`echo $line |awk '{print $1}'`
				b=`echo $line |awk '{print $2}'`
				c=`echo $line |awk '{print $3}'`
				d=`echo $line |awk '{print $4}'`
				e=`echo $line |awk '{print $5}'`
				f=`echo $line |awk '{print $6}'`
				g=`echo $line |awk '{print $7}'`
				h=`echo $line |awk '{print $8}'`
				i=`echo $line |awk '{print $9}'`
				j=`echo $line |awk '{print $10}'`
				k=`echo $line |awk '{print $11}'`
				l=`echo $line |awk '{print $12}'`
				m=`echo $line |awk '{printf "%3i", $3}'`

				if [ $m -ge $pp_ctf3 ] && [ $d -ge 70 ]; then
				    p=`echo $b | cut -d "|" -f3 | cut -d ":" -f1`
				    q=`echo $p | cut -d "_" -f2`
				    r=`echo $b |cut -d "|" -f4`
				    if [[ -z "$r" ]]
				    then
					r=`echo $b | cut -d ":" -f2`
				    fi
				    s=`echo $b |cut -d "|" -f2`
				    echo -e "$q   - $r   - $c   - $d   - $l - $s">>resulvt_$xx.txt
				    if [ $m -ge $pp_ctf3 ]
				    then
					echo -e "$q" >> sertp_$xx.txt

				    fi

				else
				    continue;
				fi
			    done<serout_$xx.out
			    cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> sult_$xx.txt
			    fln=`cat resulvt_$xx.txt |awk '{print $1}' | sort -k1 -u | tr '[:upper:]' '[:lower:]'`
			    cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> $fln.txt
			    echo $sergn > new_combine.txt
			else
			    echo $sergn_"variant" > new_combine.txt
			fi

		    done
		    
		else
		    yx=`grep -L $sergn sult*.txt | wc -l`

		    for (( nyx=1; nyx<=$yx; nyx=$nyx+1 ))
		    do
			xx=`grep -L $sergn sult*.txt | head -$nyx | tail -1 | cut -d "_" -f2 | cut -d "." -f1`
			
			grep -i $sergn"|" output_$xx.out | awk '$3 >= 95.0' > serout_$xx.out

			if [ -s "serout_$xx.out" ]
			then
			    while read -r line || [[ -n $line ]]; do
				a=`echo $line |awk '{print $1}'`
				b=`echo $line |awk '{print $2}'`
				c=`echo $line |awk '{print $3}'`
				d=`echo $line |awk '{print $4}'`
				e=`echo $line |awk '{print $5}'`
				f=`echo $line |awk '{print $6}'`
				g=`echo $line |awk '{print $7}'`
				h=`echo $line |awk '{print $8}'`
				i=`echo $line |awk '{print $9}'`
				j=`echo $line |awk '{print $10}'`
				k=`echo $line |awk '{print $11}'`
				l=`echo $line |awk '{print $12}'`
				m=`echo $line |awk '{printf "%3i", $3}'`
				
				if [ $m -ge $pp_ctf3 ] && [ $d -ge 70 ]; then
				    p=`echo $b | cut -d "|" -f3 | cut -d ":" -f1`
				    q=`echo $p | cut -d "_" -f2`
				    r=`echo $b |cut -d "|" -f4`
				    if [[ -z "$r" ]]
				    then
					r=`echo $b | cut -d ":" -f2`
				    fi
				    s=`echo $b |cut -d "|" -f2`
				    echo -e "$q   - $r   - $c   - $d   - $l - $s">>resulvt_$xx.txt
				    if [ $m -ge $pp_ctf3 ]
				    then
					echo -e "$q" >> sertp_$xx.txt
					
				    fi

				else
				    continue;
				fi
			    done<serout_$xx.out
			    cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> sult_$xx.txt
			    fln=`cat resulvt_$xx.txt |awk '{print $1}' | sort -k1 -u | tr '[:upper:]' '[:lower:]'`
			    cat resulvt_$xx.txt |awk '{print $1}' | sort -k1 -u >> $fln.txt
			    echo $sergn >> new_combine.txt
			else
			    continue
			fi
			
		    done
		fi    
	    fi
	    
	    
	else
	    echo "New_Serotype" > new_combine.txt
	fi
    done

elif [ $chtn -eq 1 ]
then
    if [ "$serchtn" == "k33" ] || [ "$serchtn" == "k40" ]
    then
	rm wzi.txt
    elif [ "$serchtn" == "k34" ]
    then
	rm wzx.txt
    elif [ "$serchtn" == "k50" ]
    then
	rm wzb.txt wzc.txt wzx.txt wzy.txt
    elif [ "$serchtn" == "k29" ] || [ "$serchtn" == "k71" ] || [ "$serchtn" == "kl108" ] || [ "$serchtn" == "kl109" ]
    then
	rm wzy.txt
    elif [ "$serchtn" == "kl110" ] || [ "$serchtn" == "kl113" ] || [ "$serchtn" == "kl116" ] || [ "$serchtn" == "kl118" ]
    then
	rm wzy.txt
    fi

    sergn=$serchtn
    nsergn=`bash link2.sh | grep -i "sult" | grep -i $sergn | awk '{print $1}' | awk -F'/' '{ print NF }'`
    sltcnt=`ls sult*.txt | wc -l`
    w_cnt=`ls w*.txt | wc -l`
    ls sult*.txt
    ls w*.txt
        
    if [ $nsergn -eq 7 ]
    then

	echo $sergn > new_combine.txt

    elif [ $nsergn -lt 7 ] && [ $nsergn -ge 4 ]
    then
	if [ $sltcnt -eq $w_cnt ]
	then
	    echo "entry1"
	    echo "sltcnt: $sltcnt"
	    echo "w_cnt: $w_cnt"
	    
	    zx=`ls sult*.txt | wc -l`
	    if [ $nsergn -eq zx ]
	    then
		echo $sergn > new_combine.txt
		   
	    else
		yx=`grep -L $sergn sult*.txt | wc -l`
		
		for (( nyx=1; nyx<=$yx; nyx=$nyx+1 ))
		do
		    xx=`grep -L $sergn sult*.txt | head -$nyx | tail -1 | cut -d "_" -f2 | cut -d "." -f1`
		    
		    grep -i $sergn"|" output_$xx.out | awk '$3 >= 95.0' > serout_$xx.out
		    
		    cp sult_$xx.txt old_sult_$xx.txt
		    rm sult_$xx.txt
		    
		    if [ -s "serout_$xx.out" ]
		    then
			while read -r line || [[ -n $line ]]; do
			    a=`echo $line |awk '{print $1}'`
			    b=`echo $line |awk '{print $2}'`
			    c=`echo $line |awk '{print $3}'`
			    d=`echo $line |awk '{print $4}'`
			    e=`echo $line |awk '{print $5}'`
			    f=`echo $line |awk '{print $6}'`
			    g=`echo $line |awk '{print $7}'`
			    h=`echo $line |awk '{print $8}'`
			    i=`echo $line |awk '{print $9}'`
			    j=`echo $line |awk '{print $10}'`
			    k=`echo $line |awk '{print $11}'`
			    l=`echo $line |awk '{print $12}'`
			    m=`echo $line |awk '{printf "%3i", $3}'`
			    
			    if [ $m -ge $pp_ctf3 ] && [ $d -ge 70 ]; then
				p=`echo $b | cut -d "|" -f3 | cut -d ":" -f1`
				q=`echo $p | cut -d "_" -f2`
				r=`echo $b |cut -d "|" -f4`
				if [[ -z "$r" ]]
				then
				    r=`echo $b | cut -d ":" -f2`
				fi
				s=`echo $b |cut -d "|" -f2`
				echo -e "$q   - $r   - $c   - $d   - $l - $s">>resulvt_$xx.txt
				if [ $m -ge $pp_ctf3 ]
				then
				    echo -e "$q" >> sertp_$xx.txt
				    
				fi
				
			    else
				continue;
			    fi
			done<serout_$xx.out
			cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> sult_$xx.txt
			fln=`cat resulvt_$xx.txt |awk '{print $1}' | sort -k1 -u | tr '[:upper:]' '[:lower:]'`
			cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> $fln.txt

			echo "entry2"
			echo "sltcnt: $sltcnt"
			echo "w_cnt: $w_cnt"
			ls sult*.txt
			ls w*.txt
			echo $sergn > new_combine.txt
		    else
			echo "entry3"
			echo "sltcnt: $sltcnt"
			echo "w_cnt: $w_cnt"
			echo $sergn"_varriant" > new_combine.txt
		    fi
		done
	    fi
	elif [ $sltcnt -lt $w_cnt ]
        then
            zx=`ls sult*.txt | wc -l`
            if [ $nsergn -eq zx ]
            then
		echo "entry4"
		echo "sltcnt: $sltcnt"
		echo "w_cnt: $w_cnt"
		ls sult*.txt
		ls w*.txt
                echo $sergn"_variiant" > new_combine.txt
		
            else
                yx=`grep -L $sergn sult*.txt | wc -l`

                for (( nyx=1; nyx<=$yx; nyx=$nyx+1 ))
                do
                    xx=`grep -L $sergn sult*.txt | head -$nyx | tail -1 | cut -d "_" -f2 | cut -d "." -f1`

                    grep -i $sergn"|" output_$xx.out | awk '$3 >= 95.0' > serout_$xx.out

                    cp sult_$xx.txt old_sult_$xx.txt
                    rm sult_$xx.txt

                    if [ -s "serout_$xx.out" ]
                    then
                        while read -r line || [[ -n $line ]]; do
                            a=`echo $line |awk '{print $1}'`
                            b=`echo $line |awk '{print $2}'`
                            c=`echo $line |awk '{print $3}'`
                            d=`echo $line |awk '{print $4}'`
                            e=`echo $line |awk '{print $5}'`
                            f=`echo $line |awk '{print $6}'`
                            g=`echo $line |awk '{print $7}'`
                            h=`echo $line |awk '{print $8}'`
                            i=`echo $line |awk '{print $9}'`
                            j=`echo $line |awk '{print $10}'`
                            k=`echo $line |awk '{print $11}'`
                            l=`echo $line |awk '{print $12}'`
                            m=`echo $line |awk '{printf "%3i", $3}'`

                            if [ $m -ge $pp_ctf3 ] && [ $d -ge 70 ]; then
                                p=`echo $b | cut -d "|" -f3 | cut -d ":" -f1`
                                q=`echo $p | cut -d "_" -f2`
                                r=`echo $b |cut -d "|" -f4`
                                if [[ -z "$r" ]]
                                then
                                    r=`echo $b | cut -d ":" -f2`
                                fi
                                s=`echo $b |cut -d "|" -f2`
                                echo -e "$q   - $r   - $c   - $d   - $l - $s">>resulvt_$xx.txt
                                if [ $m -ge $pp_ctf3 ]
                                then
                                    echo -e "$q" >> sertp_$xx.txt

                                fi

                            else
                                continue;
                            fi
                        done<serout_$xx.out
                        cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> sult_$xx.txt
                        fln=`cat resulvt_$xx.txt |awk '{print $1}' | sort -k1 -u | tr '[:upper:]' '[:lower:]'`
                        cat sertp_$xx.txt |awk '{print $1}' | sort -k1 -u >> $fln.txt

			echo "entry5"
			echo "sltcnt: $sltcnt"
			echo "w_cnt: $w_cnt"
			ls sult*.txt
			ls w*.txt
			echo $sergn"_variaant" > new_combine.txt
                    else
			echo "entry6"
			echo "sltcnt: $sltcnt"
			echo "w_cnt: $w_cnt"
			ls sult*.txt
			ls w*.txt
                        echo $sergn"_variannt" > new_combine.txt
                    fi
                done
            fi
	fi
    elif [ $nsergn -eq 3 ]
    then
	if [ "$sergn" == "k50" ]
	then
	    echo $sergn > new_combine.txt
	else
	echo "New_Serotype" > new_combine.txt
	fi
    else
	echo "New_Serotype" > new_combine.txt
    fi
else
    echo "New_Serotype" > new_combine.txt
fi


k_type=`cat new_combine.txt | tr "\n\r" ";"`

scr=`cat gnrlbl.txt | awk '{print $2}' | tr "\n\r" ","`

echo $ncnm","$k_type","$wziscr_o","$scr >> ARS_calc.csv 

mv *sult_* output_kpam/dir_$ncnm/
mv serout_* output_kpam/dir_$ncnm/
mv wz*.txt output_kpam/dir_$ncnm/
mv wbap.txt output_kpam/dir_$ncnm/
mv wcaj.txt output_kpam/dir_$ncnm/
mv sertp_* output_kpam/dir_$ncnm/
mv res*.txt output_kpam/dir_$ncnm/
mv *.out output_kpam/dir_$ncnm/
mv *new*.fasta output_kpam/dir_$ncnm/
mv align*.txt output_kpam/dir_$ncnm/
mv file*.sh output_kpam/dir_$ncnm/
mv gnrlb*.txt output_kpam/dir_$ncnm/
mv new_combine*.txt output_kpam/dir_$ncnm/
mv result*.csv output_kpam/dir_$ncnm/
 
find w*.txt -size  0 -print0 |xargs -0 rm --
